@@ -9,6 +9,12 @@ import (
 	"path"
 	"strconv"
 
+	"github.com/hashicorp/go-cleanhttp"
+	"github.com/mholt/archiver/v3"
+	"github.com/spf13/afero"
+	"github.com/wagoodman/go-partybus"
+	"github.com/wagoodman/go-progress"
+
 	grypeDB "github.com/anchore/grype/grype/db/v3"
 	"github.com/anchore/grype/grype/db/v3/reader"
 	"github.com/anchore/grype/grype/event"
@@ -16,10 +22,6 @@ import (
 	"github.com/anchore/grype/internal/bus"
 	"github.com/anchore/grype/internal/file"
 	"github.com/anchore/grype/internal/log"
-	"github.com/hashicorp/go-cleanhttp"
-	"github.com/spf13/afero"
-	"github.com/wagoodman/go-partybus"
-	"github.com/wagoodman/go-progress"
 )
 
 const (
@@ -223,18 +225,7 @@ func (c *Curator) ImportFrom(dbArchivePath string) error {
 		return fmt.Errorf("unable to create db temp dir: %w", err)
 	}
 
-	f, err := os.Open(dbArchivePath)
-	if err != nil {
-		return fmt.Errorf("unable to open archive (%s): %w", dbArchivePath, err)
-	}
-	defer func() {
-		err = f.Close()
-		if err != nil {
-			log.Errorf("unable to close archive (%s): %w", dbArchivePath, err)
-		}
-	}()
-
-	err = file.UnTarGz(tempDir, f)
+	err = archiver.Unarchive(dbArchivePath, tempDir)
 	if err != nil {
 		return err
 	}
