@@ -7,32 +7,28 @@ import (
 	"strings"
 
 	"github.com/gabriel-vasile/mimetype"
+	"github.com/mitchellh/go-homedir"
 
 	"github.com/anchore/grype/internal"
 	"github.com/anchore/grype/internal/log"
-
-	"github.com/anchore/syft/syft/format"
-
 	"github.com/anchore/syft/syft"
-
-	"github.com/mitchellh/go-homedir"
 )
 
-func syftSBOMProvider(userInput string) ([]Package, Context, error) {
+func syftSBOMProvider(userInput string, config ProviderConfig) ([]Package, Context, error) {
 	reader, err := getSBOMReader(userInput)
 	if err != nil {
 		return nil, Context{}, err
 	}
 
-	sbom, formatOption, err := syft.Decode(reader)
+	sbom, format, err := syft.Decode(reader)
 	if err != nil {
 		return nil, Context{}, fmt.Errorf("unable to decode sbom: %w", err)
 	}
-	if formatOption == format.UnknownFormatOption {
+	if format == nil {
 		return nil, Context{}, errDoesNotProvide
 	}
 
-	return FromCatalog(sbom.Artifacts.PackageCatalog), Context{
+	return FromCatalog(sbom.Artifacts.PackageCatalog, config), Context{
 		Source: &sbom.Source,
 		Distro: sbom.Artifacts.LinuxDistribution,
 	}, nil
